"use strict";

/**
 * Equivalent to array.forEach().
 *
 * @param {function} cb A predicate function.
 * @returns {MountedComponent} self.
 */
exports.each = function componentEach(cb) {
  var _this = this;

  Array.from(this._el).forEach(function (el, i) {
    var elMount = _this._newFromThis(el);
    cb.call(elMount, i, elMount);
  });

  return this;
};

/**
 * Equivalent to array.map().
 *
 * @param {function} cb A predicate function.
 * @returns {Array} Array of values returned by predicate function.
 */
exports.map = function componentMap(cb) {
  var _this2 = this;

  return Array.from(this._el).map(function (el, i) {
    var elMount = _this2._newFromThis(el);
    return cb.call(elMount, i, elMount);
  });
};

/**
 * Equivalent to array.some().
 *
 * @param {function} cb A predicate function.
 * @returns {boolean} True if predicate function returns true at least once.
 */
exports.some = function componentSome(cb) {
  var _this3 = this;

  return Array.from(this._el).some(function (el, i) {
    var elMount = _this3._newFromThis(el);
    return cb.call(elMount, i, elMount);
  });
};

/**
 * Equivalent to array.every().
 *
 * @param {function} cb A predicate function.
 * @returns {boolean} True if predicate function returns true every time.
 */
exports.every = function componentEvery(cb) {
  var _this4 = this;

  return Array.from(this._el).every(function (el, i) {
    var elMount = _this4._newFromThis(el);
    return cb.call(elMount, i, elMount);
  });
};