'use strict';

require('../vendor/matches-polyfill');

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

/**
 * Find all elements within the mounted element(s) matching a given selector.
 *
 * @param {string} selector The selector to use.
 * @returns {MountedComponent} A new MountedComponent.
 */
exports.find = function componentFind(selector) {
  var found = [];

  Array.from(this._el).forEach(function (el) {
    found.push.apply(found, _toConsumableArray(el.querySelectorAll(selector)));
  });

  if (!found.length) {
    return null;
  }

  return this._newFromThis(found);
};

/**
 * Find all children of mounted element(s), optionally matching a given
 * selector.
 *
 * @param {string} [selector] The selector to filter by.
 * @returns {*}
 */
exports.children = function componentChildren(selector) {
  var children = [];

  this._el.forEach(function (el) {
    var _children;

    return (_children = children).push.apply(_children, _toConsumableArray(el.children));
  });

  if (selector) {
    children = children.filter(function (child) {
      return child.matches(selector);
    });
  }

  if (!children.length) {
    return null;
  }

  return this._newFromThis(children);
};